module.exports = function(grunt) {
    grunt.file.defaultEncoding = 'UTF-8';

    grunt.initConfig({
        pkg: grunt.file.readJSON('package.json'),
        project: {
            dist: {
                css: 'src/Resources/public/css/',
                js: 'src/Resources/public/js/dist/'
            },
            src: {
                node: 'node_modules/',
                js: 'src/Resources/public/js/src/',
                vendor: 'src/Resources/public/js/vendor/',
                scss: 'src/Resources/public/sass/'
            }
        },
        sass: {
            dist: {
                options: {
                    style: 'expanded',
                    trace: true,
                    compass: false,
                    sourcemap: 'none'
                },
                files: [
                    {
                        expand: true,
                        cwd: '<%= project.src.scss %>',
                        src: 'main.scss',
                        dest: '<%= project.dist.css %>',
                        ext: '.css'
                    }
                ]
            }
        },
        concat: {
            css: {
                src: [
                    '<%= project.dist.css %>vendor/*',
                    '<%= project.dist.css %>main.css'
                ],
                dest: '<%= project.dist.css %>main.css'
            },
            js: {
                src: [
                    '<%= project.src.node %>jquery/dist/jquery.min.js',
                    '<%= project.src.node %>Hinclude/hinclude.js',
                    '<%= project.src.node %>jquery-form/jquery.form.js',
                    '<%= project.src.vendor %>*',
                    '<%= project.src.js %>form/*',
                    '<%= project.src.js %>lib/*',
                    '<%= project.src.js %>main.js'
                ],
                dest: '<%= project.dist.js %>main.js'
            }
        },
        cssmin: {
            dist: {
                files: {
                    '<%= project.dist.css %>main.min.css': '<%= project.dist.css %>main.css'
                }
            }
        },
        uglify: {
            options: {
                banner: '/* This file is auto-generated by grant at <%= grunt.template.today("yyyy-mm-dd") %> */\n',
                compress: {
                    drop_console: true
                }
            },
            build: {
                files: {
                    '<%= project.dist.js %>main.min.js': '<%= project.dist.js %>main.js'
                }
            }
        }
    });

    grunt.loadNpmTasks('grunt-contrib-sass');
    grunt.loadNpmTasks('grunt-contrib-cssmin');
    grunt.loadNpmTasks('grunt-contrib-concat');
    grunt.loadNpmTasks('grunt-contrib-uglify');

    grunt.registerTask('default', [
        'sass',
        'concat',
        'cssmin',
        'uglify'
    ]);
};